@@ -548,7 +548,7 @@ class APFSDMccSolver(ABCSolver):
 
         bt_mc = balltip['mass_center']
         bt_mass = balltip['mass']
-        total_len = balltip['mass_center']
+        total_len = p_data['l_n']
 
         ker_mc = kernel['mass_center'] + total_len
         ker_mass = kernel['mass']
