@@ -544,14 +544,24 @@ class ConstrainedOptimizer:
         _error_list = []
 
         constaint_status = 0
-        for i in range(n_iters):
-            res = base_optimizer.optimize(problem, print_limit)
-            _x_history.extend(res.x_history)
-            _f_history.extend(res.f_history)
-            _global_state_history.extend(res.global_state_history)
-            _mask.extend(res.step_mask)
 
-            if res.status_code == 1:
+        res = base_optimizer.optimize(problem, print_limit)
+        if res.status_code == 1:
+            return res, constaint_status
+        problem(res.x_history[res.step_mask][-1])
+        factor = problem.constraint_factor
+        if factor < tol:
+            constaint_status = 1
+            return res, constaint_status
+
+        for i in range(n_iters):
+            res_1 = base_optimizer.optimize(problem, print_limit)
+            _x_history.extend(res_1.x_history)
+            _f_history.extend(res_1.f_history)
+            _global_state_history.extend(res_1.global_state_history)
+            _mask.extend(res_1.step_mask)
+
+            if res_1.status_code == 1:
                 return OptResult(x_history=np.array(_x_history),
                                  f_history=np.array(_f_history),
                                  step_mask=np.array(_mask),
@@ -561,7 +571,8 @@ class ConstrainedOptimizer:
                                  error_list=_error_list
                                  ), constaint_status
 
-            problem(res.x_history[-1])
+            # problem(res.x_history[-1])
+            problem(res.x_history[res_1.step_mask][-1])
             factor = problem.constraint_factor
             problem.callback()
 
@@ -575,6 +586,7 @@ class ConstrainedOptimizer:
                                  status_message=res.status_message,
                                  error_list=_error_list
                                  ), constaint_status
+            res = res_1
             problem.modify_constraint()
 
         return OptResult(x_history=np.fromiter(_x_history, dtype=np.dtype((float, _x_history[0].shape))),
